[Swift-commit] r7138 - in trunk/tests: . groups multi_remote sites sites/bridled sites/communicado sites/fusion stress/IO/bagOnodes stress/IO/beagle stress/internals

yadunandb at ci.uchicago.edu yadunandb at ci.uchicago.edu
Sun Oct 6 14:51:29 CDT 2013


Author: yadunandb
Date: 2013-10-06 14:51:29 -0500 (Sun, 06 Oct 2013)
New Revision: 7138

Added:
   trunk/tests/groups/group-remote-sanity.sh
   trunk/tests/sites/bridled/
   trunk/tests/sites/bridled/bridled_sanity.setup.sh
   trunk/tests/sites/bridled/bridled_sanity.source.sh
   trunk/tests/sites/bridled/bridled_sanity.swift
   trunk/tests/sites/bridled/bridled_sanity.timeout
   trunk/tests/sites/bridled/sites.template.xml
   trunk/tests/sites/bridled/swift.properties
   trunk/tests/sites/bridled/tc.template.data
   trunk/tests/sites/bridled/title.txt
   trunk/tests/sites/communicado/
   trunk/tests/sites/communicado/communicado_sanity.setup.sh
   trunk/tests/sites/communicado/communicado_sanity.source.sh
   trunk/tests/sites/communicado/communicado_sanity.swift
   trunk/tests/sites/communicado/communicado_sanity.timeout
   trunk/tests/sites/communicado/sites.template.xml
   trunk/tests/sites/communicado/swift.properties
   trunk/tests/sites/communicado/tc.template.data
   trunk/tests/sites/communicado/title.txt
   trunk/tests/sites/fusion/
   trunk/tests/sites/fusion/fusion_sanity.setup.sh
   trunk/tests/sites/fusion/fusion_sanity.source.sh
   trunk/tests/sites/fusion/fusion_sanity.swift
   trunk/tests/sites/fusion/fusion_sanity.timeout
   trunk/tests/sites/fusion/sites.template.xml
   trunk/tests/sites/fusion/swift.properties
   trunk/tests/sites/fusion/tc.template.data
   trunk/tests/sites/fusion/title.txt
   trunk/tests/user_test.sh
   trunk/tests/user_yadu.sh
Modified:
   trunk/tests/groups/group-daily-remote.sh
   trunk/tests/groups/group-stress-heavy.sh
   trunk/tests/multi_remote/remote_driver.check.sh
   trunk/tests/multi_remote/remote_driver.setup.sh
   trunk/tests/multi_remote/remote_driver.source.sh
   trunk/tests/multi_remote/remote_driver.swift
   trunk/tests/multi_remote/sites.template.xml
   trunk/tests/multi_remote/tc.template.data
   trunk/tests/stress/IO/bagOnodes/sites.template.xml
   trunk/tests/stress/IO/beagle/sites.template.xml
   trunk/tests/stress/internals/swift.properties
   trunk/tests/stress/internals/tc.template.data
   trunk/tests/stress/internals/x_foreach.swift
   trunk/tests/stress/internals/x_recursion.args
Log:

Committing to latest working state of test-suite



Modified: trunk/tests/groups/group-daily-remote.sh
===================================================================
--- trunk/tests/groups/group-remote-sanity.sh	                        (rev 0)
+++ trunk/tests/groups/group-remote-sanity.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,17 @@
+# GROUPLIST definition to run all local tests
+
+GROUPLIST=( # Site testing test-group
+            $TESTDIR/sites/beagle \
+            $TESTDIR/sites/mcs    \
+            $TESTDIR/sites/midway \
+            $TESTDIR/sites/uc3    \
+	        # Frisbee will fail due to Bug 1030
+            $TESTDIR/sites/mac-frisbee  \
+            $TESTDIR/sites/blues  \
+            $TESTDIR/sites/fusion \
+            $TESTDIR/sites/raven  \
+            $TESTDIR/sites/communicado \
+            $TESTDIR/sites/bridled \
+          )
+
+checkvars WORK

Modified: trunk/tests/groups/group-stress-heavy.sh
===================================================================
--- trunk/tests/groups/group-stress-heavy.sh	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/groups/group-stress-heavy.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -1,8 +1,11 @@
 # GROUPLIST definition to run all local tests                            \
 
 GROUPLIST=(
-#             $TESTDIR/stress/IO \
-             $TESTDIR/stress/internals \
+#            $TESTDIR/stress/IO/beagle \
+#            $TESTDIR/stress/IO/bagOnodes \
+#            $TESTDIR/stress/IO/multiple \
+#            $TESTDIR/stress/IO/uc3 \
+           $TESTDIR/stress/internals \
           )
 
 checkvars WORK
\ No newline at end of file

Modified: trunk/tests/multi_remote/remote_driver.check.sh
===================================================================
--- trunk/tests/multi_remote/remote_driver.check.sh	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/multi_remote/remote_driver.check.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -1,43 +1,111 @@
 #!/bin/bash
 
+PUBLISH_LOCATION=/scratch/midway/yadunand/publish
+PUBLISH_SERVER=http://swift.rcc.uchicago.edu:8042
+DATE=$(date +%H%M%S)
+
+[ ! -z $FROM_MAIL ] || FROM_MAIL="test-engine at swift.rcc.uchicago"
+[ ! -z $TO_MAIL ]   || TO_MAIL="yadudoc1729 at gmail.com"
+
 if [ -d "swift" ]
 then
-    rm -rf swift swift.tar    
+    rm -rf swift swift.tar
 fi
 
 SITES_PASSED=`ls out/*out | wc -l`
 HOME=$PWD
 MAIL="$HOME/Mail.content"
+#VERSION=`grep "^Swift.*swift-.*cog.*" remote_driver.stdout  | cut -d " " -f -2 | sed 's/\ /-/g' | tr '[A-Z]' '[a-z]'`
+VERSION="swift-trunk"
 
 cd out;
 echo "Test-Results"                         >  $MAIL
-echo "=====================================">> $MAIL
+echo "==========================================================================">> $MAIL
 echo "Test home         : $PWD"             >> $MAIL
 echo "Sites successful  : $SITES_PASSED"    >> $MAIL
-VERSION=`swift -version | cut -d " " -f -2 | sed 's/\ /-/g' | tr '[A-Z]' '[a-z]'`
+#VERSION=`swift -version | cut -d " " -f -2 | sed 's/\ /-/g' | tr '[A-Z]' '[a-z]'`
 for i in `ls *tar`
 do
-    scp $i ci:~/public_html/$VERSION/
+    echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++">> $MAIL
+    #scp $i ci:~/public_html/$VERSION/
     tar -xf $i
-    folder=`tar -tf $i | head -n 1`
+    folder=`tar -tf $i | head -n 1 | sed 's/\/$//'`
     echo "Results for site : $folder"              >> $MAIL
-    grep "Tests run" $folder/run*/tests*html       >> $MAIL
-    grep "Tests succeeded" $folder/run*/tests*html >> $MAIL
-    grep "Tests failed" $folder/run*/tests*html    >> $MAIL
-    grep "Total Time" $folder/run*/tests*html      >> $MAIL
-    echo ""
-    rm -rf $folder
+
+    echo "GROUPS" | awk '{printf "%-40s\n", $0}' > t0
+    grep "Group" $folder/tests*html | sed 's/Group\ /G/' | cut -c -40 | awk '{printf "%-40s\n", $0}'  >> t0
+
+    echo "RUN "    | awk '{printf "%-5s\n", $0}'  >t1
+    grep "Tests run" $folder/tests*html       | sed 's/Tests\ run//'  | awk '{printf "%-5s\n", $0}'    >> t1
+
+    echo "PASS"   | awk '{printf "%-5s\n", $0}'  >t2
+    grep "Tests succeeded" $folder/tests*html | sed 's/Tests\ succeeded.//' | awk '{printf "%-5s\n", $0}'  >> t2
+
+    echo "FAIL"   | awk '{printf "%-5s\n", $0}'  >t3
+    grep "Tests failed" $folder/tests*html    | sed 's/Tests\ failed.//' | awk '{printf "%-5s\n", $0}'  >> t3
+
+    echo "TIME"   | awk '{printf "%-40s\n", $0}' >t4
+    grep "Total Time" $folder/tests*html      | sed 's/Total\ Time://'  | awk '{printf "%-5s\n", $0}' >> t4
+
+    pr -s'|' -tm t0 t1 t2 t3 t4 >> $MAIL
+    rm t{0,1,2,3,4}
+    HTML=$(basename $(ls $folder/tests*html))
+    echo "Link: $PUBLISH_SERVER/$VERSION/$folder-$DATE/$HTML" >> $MAIL
+    mkdir -p $PUBLISH_LOCATION/$VERSION
+    mv $folder $PUBLISH_LOCATION/$VERSION/$folder-$DATE
 done
 cd $HOME;
 cd ..;
 RUN_DIR=$(basename $PWD);
 cd ..;
+
+folder=$RUN_DIR
+HTML=$(basename $(ls $folder/tests*html))
+
+echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++">> $MAIL
+echo "Results for site : LOCAL at $RUN_DIR-$DATE"              >> $MAIL
+echo "GROUPS" | awk '{printf "%-40s\n", $0}' > t0
+grep "Group" $folder/tests*html | sed 's/Group\ /G/' | cut -c -40 | awk '{printf "%-40s\n", $0}'  >> t0
+
+echo "RUN "    | awk '{printf "%-5s\n", $0}'  >t1
+grep "Tests run" $folder/tests*html       | sed 's/Tests\ run//'  | awk '{printf "%-5s\n", $0}'    >> t1
+
+echo "PASS"   | awk '{printf "%-5s\n", $0}'  >t2
+grep "Tests succeeded" $folder/tests*html | sed 's/Tests\ succeeded.//' | awk '{printf "%-5s\n", $0}'  >> t2
+
+echo "FAIL"   | awk '{printf "%-5s\n", $0}'  >t3
+grep "Tests failed" $folder/tests*html    | sed 's/Tests\ failed.//' | awk '{printf "%-5s\n", $0}'  >> t3
+
+echo "TIME"   | awk '{printf "%-40s\n", $0}' >t4
+grep "Total Time" $folder/tests*html      | sed 's/Total\ Time://'  | awk '{printf "%-5s\n", $0}' >> t4
+
+pr -s'|' -tm t0 t1 t2 t3 t4 >> $MAIL
+rm t{0,1,2,3,4}
+
+echo "RUN_DIR = $RUN_DIR"
+echo "Moving $RUN_DIR to $PUBLISH_LOCATION/$RUN_DIR-$DATE"
+echo "Link: $PUBLISH_SERVER/$VERSION/$RUN_DIR-$DATE/$HTML"  >> $MAIL
+echo "==========================================================================">> $MAIL
+cat $MAIL
+mailx -s "Test results from $HOSTNAME" -r $FROM_MAIL $TO_MAIL  < $MAIL
+
+cp -R $folder $PUBLISH_LOCATION/$VERSION/$RUN_DIR-$DATE &
+exit 0
+
+#########################################################################################
+############# SUBMIT Results to CI##############
+cd $HOME;
+cd ..;
+RUN_DIR=$(basename $PWD);
+cd ..;
+echo "mv $RUN_DIR \"$RUN_DIR-local\" "
+
 mv $RUN_DIR "$RUN_DIR-local"
 tar -cf Local.tar "$RUN_DIR-local"
 scp Local.tar ci:~/public_html/$VERSION/
 
 echo "Running update and maintenance script on publish server";
-ssh ci "cd ~/public_html/$VERSION/; ./maint.sh"
+#ssh ci "cd ~/public_html/$VERSION/; cp ~/bin/maint.sh .;  ./maint.sh"
 mv "$RUN_DIR-local" $RUN_DIR
 rm Local.tar
 

Modified: trunk/tests/multi_remote/remote_driver.setup.sh
===================================================================
--- trunk/tests/multi_remote/remote_driver.setup.sh	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/multi_remote/remote_driver.setup.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -3,8 +3,6 @@
 #CLEAN_CHECKOUT="yes"
 CLEAN_CHECKOUT="no"
 
-#[ ! -z $COG_URL ]         || COG_URL=https://cogkit.svn.sourceforge.net/svnroot/cogkit/branches/4.1.10/src/cog
-#[ ! -z $SWIFT_URL ]       || SWIFT_URL=https://svn.ci.uchicago.edu/svn/vdl2/branches/release-0.94
 [ ! -z $COG_URL ]         || COG_URL=https://svn.code.sf.net/p/cogkit/svn/trunk/src/cog
 [ ! -z $SWIFT_URL ]       || SWIFT_URL=https://svn.ci.uchicago.edu/svn/vdl2/trunk
 [ ! -z $SWIFT_VERSION ]   || SWIFT_VERSION=trunk
@@ -12,10 +10,14 @@
 [ ! -z $MIDWAY_USERNAME ] || MIDWAY_USERNAME="yadunand"
 [ ! -z $UC3_USERNAME ]    || UC3_USERNAME="yadunand"
 [ ! -z $MCS_USERNAME ]    || MCS_USERNAME="yadunand"
+[ ! -z $FUSION_USERNAME ] || FUSION_USERNAME="yadunand"
+[ ! -z $BLUES_USERNAME ]  || BLUES_USERNAME="yadunand"
+[ ! -z $BRID_USERNAME ]   || BRID_USERNAME="yadunandb" # Bridled
+[ ! -z $COMM_USERNAME ]   || COMM_USERNAME="yadunandb" # Communicado
 [ ! -z $PUBLISH_FOLDER ]  || PUBLISH_FOLDER="\/home\/yadunandb\/public_html\/results"
 [ ! -z $SWIFT_SOURCE ]    || SWIFT_SOURCE="/home/yadunand/swift"
 [ ! -z $RUN_TYPE ]        || RUN_TYPE="daily"
-
+[ ! -z $SWIFT_TAR_FILE ]  || SWIFT_TAR_FILE="/scratch/midway/yadunand/swift-trunk.tar"
 SITES="sites.xml"
 cp  $SITES  $SITES.bak
 cat $SITES | sed "s/BEAGLE_USERNAME/$BEAGLE_USERNAME/g" > tmp && mv tmp $SITES
@@ -23,15 +25,18 @@
 cat $SITES | sed "s/UC3_USERNAME/$UC3_USERNAME/g"       > tmp && mv tmp $SITES
 cat $SITES | sed "s/MCS_USERNAME/$MCS_USERNAME/g"       > tmp && mv tmp $SITES
 cat $SITES | sed "s/PUBLISH_FOLDER/$PUBLISH_FOLDER/g"   > tmp && mv tmp $SITES
+cat $SITES | sed "s/BRID_USERNAME/$BRID_USERNAME/g"     > tmp && mv tmp $SITES
+cat $SITES | sed "s/COMM_USERNAME/$COMM_USERNAME/g"     > tmp && mv tmp $SITES
+cat $SITES | sed "s/FUSION_USERNAME/$FUSION_USERNAME/g" > tmp && mv tmp $SITES
+cat $SITES | sed "s/BLUES_USERNAME/$BLUES_USERNAME/g"   > tmp && mv tmp $SITES
 
-
 export GLOBUS_HOSTNAME="swift.rcc.uchicago.edu"
 
 BASE=$PWD
 # Make clean checkout if no swift dir is present or
 # Clean checkout requested
 
-[ -f "/scratch/midway/yadunand/swift.tar" ] && cp /scratch/midway/yadunand/swift.tar ./
+[ -f "$SWIFT_TAR_FILE" ] && cp $SWIFT_TAR_FILE ./swift.tar
 
 if [ "$REMOTE_DRIVER_FASTSETUP" == "true" ]
 then
@@ -42,7 +47,7 @@
 	echo "Found swift.tar. Extracting.."
 	tar -xf swift.tar
     fi
-    
+
     if [ "CLEAN_CHECKOUT" == "yes" ] || [ ! -d "swift" ]
     then
 	echo "Cleaning and making fresh checkout"

Modified: trunk/tests/multi_remote/remote_driver.source.sh
===================================================================
--- trunk/tests/multi_remote/remote_driver.source.sh	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/multi_remote/remote_driver.source.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -2,5 +2,4 @@
 if [ "$HOSTNAME" == "midway001" ]
 then
    export GLOBUS_HOSTNAME=swift.rcc.uchicago.edu
-   export GLOBUS_TCP_PORT_RANGE=50000,51000
 fi;

Modified: trunk/tests/multi_remote/remote_driver.swift
===================================================================
--- trunk/tests/multi_remote/remote_driver.swift	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/multi_remote/remote_driver.swift	2013-10-06 19:51:29 UTC (rev 7138)
@@ -9,7 +9,7 @@
 file err[] <simple_mapper;prefix="out/driver", suffix=".err">;
 file log[] <simple_mapper;prefix="out/Logs_",  suffix=".tar">;
 
-string sites[] = ["uc3", "beagle", "midway", "crush", "frisbee"];
+string sites[] = ["uc3", "beagle", "midway", "crush", "frisbee", "blues", "fusion", "bridled", "communicado"];
 
 app (file out, file err, file log) remote_uc3	  (script run, file tar)
 {
@@ -36,6 +36,27 @@
     fsb @run @filename(tar) @log stdout=@filename(out) stderr=@filename(err);
 }
 
+app (file out, file err, file log) remote_blues   (script run, file tar)
+{
+    blu @run @filename(tar) @log stdout=@filename(out) stderr=@filename(err);
+}
+
+app (file out, file err, file log) remote_fusion  (script run, file tar)
+{
+    fus @run @filename(tar) @log stdout=@filename(out) stderr=@filename(err);
+}
+
+app (file out, file err, file log) remote_communicado  (script run, file tar)
+{
+    com @run @filename(tar) @log stdout=@filename(out) stderr=@filename(err);
+}
+
+app (file out, file err, file log) remote_bridled  (script run, file tar)
+{
+    bri @run @filename(tar) @log stdout=@filename(out) stderr=@filename(err);
+}
+
+
 app (file out, file err) publish_results (script publish, file tar, file out, file err)
 {
     pub @publish stdout=@out stderr=@err;
@@ -50,21 +71,35 @@
 
     switch(i)
     {
-	case 0: 
-	     	tracef("Calling uc3\n");
-		//(out[i], err[i], log[i]) = remote_uc3     (wrapper, swift_package);
+	case 0:
+        tracef("Calling uc3\n");
+  		(out[i], err[i], log[i]) = remote_uc3     (wrapper, swift_package);
 	case 1:
-	     	tracef("Calling beagle \n");
-		//(out[i], err[i], log[i]) = remote_beagle (wrapper, swift_package);
-	case 2: 
-	     	tracef("Calling Midway\n");	     	
-		//(out[i], err[i], log[i]) = remote_midway (wrapper, swift_package);
-	case 3: 
-	     	tracef("Crush on MCS\n");
-		(out[i], err[i], log[i]) = remote_crush(wrapper, swift_package);
-	case 4:	
-     	     	tracef("Skipping Frisbee on MCS (Will fail due to BUG:1030)\n");
-		//(out[i], err[i], log[i]) = remote_frisbee(wrapper, swift_package);
+        tracef("Calling beagle \n");
+  		(out[i], err[i], log[i]) = remote_beagle  (wrapper, swift_package);
+	case 2:
+        tracef("Skipping Midway : Tests will be run locally\n");
+		(out[i], err[i], log[i]) = remote_midway  (wrapper, swift_package);
+	case 3:
+        tracef("Calling thwomp on MCS\n");
+        (out[i], err[i], log[i]) = remote_mcs     (wrapper, swift_package);
+	case 4:
+        tracef("Skipping Frisbee on MCS (Will fail due to BUG:1030)\n");
+		//(out[i], err[i], log[i]) = remote_frisbee (wrapper, swift_package);
+	case 5:
+        tracef("Calling Blues\n");
+    	(out[i], err[i], log[i]) = remote_blues   (wrapper, swift_package);
+	case 6:
+        tracef("Calling Fusion\n");
+   		(out[i], err[i], log[i]) = remote_fusion  (wrapper, swift_package);
+	case 7:
+        tracef("Calling Communicado\n");
+		(out[i], err[i], log[i]) = remote_communicado  (wrapper, swift_package);
+	case 8:
+        tracef("Calling Bridled\n");
+		(out[i], err[i], log[i]) = remote_bridled  (wrapper, swift_package);
+
+
 	default:
 		tracef("Fail: Unknown site %s : %i \n", site, i);
     }

Modified: trunk/tests/multi_remote/sites.template.xml
===================================================================
--- trunk/tests/multi_remote/sites.template.xml	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/multi_remote/sites.template.xml	2013-10-06 19:51:29 UTC (rev 7138)
@@ -1,4 +1,5 @@
-<config>
+<?xml version="1.0" encoding="UTF-8"?>
+<config xmlns="http://www.ci.uchicago.edu/swift/SwiftSites">
 
   <pool handle="local">
     <execution provider="coaster" jobmanager="local:local"/>
@@ -47,12 +48,47 @@
     <workdirectory>/tmp/BEAGLE_USERNAME/swiftwork</workdirectory>
   </pool>
 
+  <pool handle="blues">
+    <execution jobmanager="ssh-cl:local" provider="coaster" url="blogin1.lcrc.anl.gov"/>
+    <filesystem provider="local" url="none" />
+    <profile namespace="globus" key="maxtime">3600</profile>
+    <profile namespace="globus" key="maxtime">36000</profile>
+    <profile namespace="globus" key="maxWalltime">01:05:00</profile>
+    <profile namespace="globus" key="jobsPerNode">2</profile>
+    <profile namespace="globus" key="ppn">8</profile>
+    <profile namespace="globus" key="queue">route</profile>
+    <profile namespace="globus" key="slots">1</profile>
+    <profile namespace="globus" key="nodeGranularity">2</profile>
+    <profile namespace="globus" key="maxNodes">2</profile>
+    <profile namespace="karajan" key="jobThrottle">2.20</profile>
+    <profile namespace="karajan" key="initialScore">10000</profile>
+    <profile namespace="globus" key="HighOverAllocation">1000</profile>
+    <profile namespace="globus" key="LowOverAllocation">1000</profile>
+    <workdirectory>/tmp/BLUES_USERNAME/swiftwork</workdirectory>
+  </pool>
 
+  <pool handle="fusion">
+    <execution jobmanager="ssh-cl:local" provider="coaster" url="flogin1.lcrc.anl.gov"/>
+    <filesystem provider="local" url="none" />
+    <profile namespace="globus" key="maxtime">4000</profile>
+    <profile namespace="globus" key="maxWalltime">01:05:00</profile>
+    <profile namespace="globus" key="jobsPerNode">2</profile>
+    <profile namespace="globus" key="slots">1</profile>
+    <profile namespace="globus" key="nodeGranularity">2</profile>
+    <profile namespace="globus" key="maxNodes">2</profile>
+    <profile namespace="globus" key="queue">shared</profile>
+    <profile namespace="karajan" key="jobThrottle">5.99</profile>
+    <profile namespace="karajan" key="initialScore">10000</profile>
+    <profile namespace="globus" key="HighOverAllocation">1000</profile>
+    <profile namespace="globus" key="LowOverAllocation">1000</profile>
+    <workdirectory>/homes/FUSION_USERNAME/swiftwork</workdirectory>
+  </pool>
+
   <pool handle="midway">
     <execution provider="coaster" jobmanager="local:local"/>
     <profile namespace="globus" key="queue">sandyb</profile>
     <profile namespace="globus" key="jobsPerNode">16</profile>
-    <profile namespace="globus" key="maxTime">36000</profile>
+    <profile namespace="globus" key="maxtime">36000</profile>
     <profile namespace="globus" key="maxWalltime">01:05:00</profile>
     <profile namespace="globus" key="highOverAllocation">100</profile>
     <profile namespace="globus" key="lowOverAllocation">100</profile>
@@ -95,18 +131,42 @@
     <workdirectory>/sandbox/MCS_USERNAME/swiftwork</workdirectory>
   </pool>
 
-
   <pool handle="frisbee">
     <execution provider="coaster" jobmanager="ssh-cl:local" url="frisbee.mcs.anl.gov"/>
     <profile namespace="globus" key="jobsPerNode">8</profile>
     <profile namespace="globus" key="lowOverAllocation">100</profile>
     <profile namespace="globus" key="highOverAllocation">100</profile>
-    <profile namespace="globus" key="maxtime">3600</profile>
-    <profile namespace="globus" key="maxWalltime">00:05:00</profile>
+    <profile namespace="globus" key="maxtime">4000</profile>
+    <profile namespace="globus" key="maxWalltime">01:05:00</profile>
     <profile namespace="karajan" key="jobThrottle">0.0799</profile>
     <profile namespace="karajan" key="initialScore">10000</profile>
     <workdirectory>/sandbox/MCS_USERNAME/swiftwork</workdirectory>
   </pool>
 
-  
+  <pool handle="bridled">
+    <execution provider="coaster" jobmanager="ssh-cl:local" url="bridled.ci.uchicago.edu"/>
+    <profile namespace="globus" key="jobsPerNode">2</profile>
+    <profile namespace="globus" key="lowOverAllocation">100</profile>
+    <profile namespace="globus" key="highOverAllocation">100</profile>
+    <profile namespace="globus" key="maxtime">36000</profile>
+    <profile namespace="globus" key="maxWalltime">01:05:00</profile>
+    <profile namespace="karajan" key="jobThrottle">0.0799</profile>
+    <profile namespace="karajan" key="initialScore">10000</profile>
+    <profile namespace="globus" key="userHomeOverride">/home/BRID_USERNAME/swiftwork</profile>
+    <workdirectory>/home/BRID_USERNAME/swiftwork</workdirectory>
+  </pool>
+
+  <pool handle="communicado">
+    <execution provider="coaster" jobmanager="ssh-cl:local" url="communicado.ci.uchicago.edu"/>
+    <profile namespace="globus" key="jobsPerNode">2</profile>
+    <profile namespace="globus" key="lowOverAllocation">100</profile>
+    <profile namespace="globus" key="highOverAllocation">100</profile>
+    <profile namespace="globus" key="maxtime">36000</profile>
+    <profile namespace="globus" key="maxWalltime">01:05:00</profile>
+    <profile namespace="karajan" key="jobThrottle">0.0799</profile>
+    <profile namespace="karajan" key="initialScore">10000</profile>
+    <profile namespace="globus" key="userHomeOverride">/home/COMM_USERNAME/swiftwork</profile>
+    <workdirectory>/home/COMM_USERNAME/swiftwork</workdirectory>
+  </pool>
+
 </config>

Modified: trunk/tests/multi_remote/tc.template.data
===================================================================
--- trunk/tests/multi_remote/tc.template.data	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/multi_remote/tc.template.data	2013-10-06 19:51:29 UTC (rev 7138)
@@ -1,6 +1,11 @@
-beagle    bgl /bin/bash null null null
-uc3       uc3 /bin/bash null null null
-midway    mid /bin/bash null null null
-mcs	      mcs /bin/bash null null null
-local  l_bash /bin/bash null null null
-ci        pub /bin/bash null null null
\ No newline at end of file
+beagle       bgl /bin/bash null null null
+uc3          uc3 /bin/bash null null null
+midway       mid /bin/bash null null null
+mcs	         mcs /bin/bash null null null
+local     l_bash /bin/bash null null null
+ci           pub /bin/bash null null null
+fusion       fus /bin/bash null null null
+blues        blu /bin/bash null null null
+frisbee      fsb /bin/bash null null null
+communicado  com /bin/bash null null null
+bridled      bri /bin/bash null null null
\ No newline at end of file

Added: trunk/tests/sites/bridled/bridled_sanity.setup.sh
===================================================================
--- trunk/tests/sites/bridled/bridled_sanity.setup.sh	                        (rev 0)
+++ trunk/tests/sites/bridled/bridled_sanity.setup.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,13 @@
+#!/bin/bash
+
+USERNAME=$BRID_USERNAME
+
+if [[ -z $USERNAME ]] 
+then
+    echo "Remote username not provided. Skipping sites configs"
+else
+    ls *xml
+    cat sites.xml  | sed "s/{env.USER}/$USERNAME/" > tmp && mv tmp sites.xml
+fi
+
+echo $GLOBUS_HOSTNAME
\ No newline at end of file


Property changes on: trunk/tests/sites/bridled/bridled_sanity.setup.sh
___________________________________________________________________
Added: svn:executable
   + *

Added: trunk/tests/sites/bridled/bridled_sanity.source.sh
===================================================================
--- trunk/tests/sites/bridled/bridled_sanity.source.sh	                        (rev 0)
+++ trunk/tests/sites/bridled/bridled_sanity.source.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,6 @@
+#!/bin/bash
+if [ "$HOSTNAME" == "midway001" ]
+then
+   export GLOBUS_HOSTNAME=swift.rcc.uchicago.edu
+   export GLOBUS_TCP_PORT_RANGE=50000,51000
+fi;


Property changes on: trunk/tests/sites/bridled/bridled_sanity.source.sh
___________________________________________________________________
Added: svn:executable
   + *

Added: trunk/tests/sites/bridled/bridled_sanity.swift
===================================================================
--- trunk/tests/sites/bridled/bridled_sanity.swift	                        (rev 0)
+++ trunk/tests/sites/bridled/bridled_sanity.swift	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,11 @@
+type file;
+
+app (file out, file err) remote_driver ()
+{
+    date stdout=@filename(out) stderr=@filename(err);
+}
+
+file driver_out <simple_mapper; prefix="sanity", suffix=".out">;
+file driver_err <simple_mapper; prefix="sanity", suffix=".err">;
+
+(driver_out, driver_err) = remote_driver();
\ No newline at end of file

Added: trunk/tests/sites/bridled/bridled_sanity.timeout
===================================================================
--- trunk/tests/sites/bridled/bridled_sanity.timeout	                        (rev 0)
+++ trunk/tests/sites/bridled/bridled_sanity.timeout	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1 @@
+300

Added: trunk/tests/sites/bridled/sites.template.xml
===================================================================
--- trunk/tests/sites/bridled/sites.template.xml	                        (rev 0)
+++ trunk/tests/sites/bridled/sites.template.xml	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,17 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<config xmlns="http://www.ci.uchicago.edu/swift/SwiftSites">
+
+  <pool handle="bridled">
+    <execution provider="coaster" jobmanager="ssh-cl:local" url="bridled.ci.uchicago.edu"/>
+    <profile namespace="globus" key="jobsPerNode">2</profile>
+    <profile namespace="globus" key="lowOverAllocation">100</profile>
+    <profile namespace="globus" key="highOverAllocation">100</profile>
+    <profile namespace="globus" key="maxtime">36000</profile>
+    <profile namespace="globus" key="maxWalltime">01:05:00</profile>
+    <profile namespace="karajan" key="jobThrottle">0.0799</profile>
+    <profile namespace="karajan" key="initialScore">10000</profile>
+    <profile namespace="globus" key="userHomeOverride">/home/{env.USER}/swiftwork</profile>
+    <workdirectory>/home/{env.USER}/swiftwork</workdirectory>
+  </pool>
+
+</config>
\ No newline at end of file

Added: trunk/tests/sites/bridled/swift.properties
===================================================================
--- trunk/tests/sites/bridled/swift.properties	                        (rev 0)
+++ trunk/tests/sites/bridled/swift.properties	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,8 @@
+use.provider.staging=true
+use.wrapper.staging=false
+wrapperlog.always.transfer=true
+execution.retries=0
+lazy.errors=false
+provider.staging.pin.swiftfiles=false
+sitedir.keep=true
+#tcp.port.range=60000,61000
\ No newline at end of file

Added: trunk/tests/sites/bridled/tc.template.data
===================================================================
--- trunk/tests/sites/bridled/tc.template.data	                        (rev 0)
+++ trunk/tests/sites/bridled/tc.template.data	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,7 @@
+local  date /bin/date null null null
+beagle date /bin/date null null null
+uc3    date /bin/date null null null
+mcs    date /bin/date null null null
+midway date /bin/date null null null
+communicado date /bin/date null null null
+bridled date /bin/date null null null
\ No newline at end of file

Added: trunk/tests/sites/bridled/title.txt
===================================================================
--- trunk/tests/sites/bridled/title.txt	                        (rev 0)
+++ trunk/tests/sites/bridled/title.txt	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1 @@
+Bridled remote sanity test

Added: trunk/tests/sites/communicado/communicado_sanity.setup.sh
===================================================================
--- trunk/tests/sites/communicado/communicado_sanity.setup.sh	                        (rev 0)
+++ trunk/tests/sites/communicado/communicado_sanity.setup.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,13 @@
+#!/bin/bash
+
+USERNAME=$COMM_USERNAME
+
+if [[ -z $USERNAME ]] 
+then
+    echo "Remote username not provided. Skipping sites configs"
+else
+    ls *xml
+    cat sites.xml  | sed "s/{env.USER}/$USERNAME/" > tmp && mv tmp sites.xml
+fi
+
+echo $GLOBUS_HOSTNAME
\ No newline at end of file


Property changes on: trunk/tests/sites/communicado/communicado_sanity.setup.sh
___________________________________________________________________
Added: svn:executable
   + *

Added: trunk/tests/sites/communicado/communicado_sanity.source.sh
===================================================================
--- trunk/tests/sites/communicado/communicado_sanity.source.sh	                        (rev 0)
+++ trunk/tests/sites/communicado/communicado_sanity.source.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,6 @@
+#!/bin/bash
+if [ "$HOSTNAME" == "midway001" ]
+then
+   export GLOBUS_HOSTNAME=swift.rcc.uchicago.edu
+   export GLOBUS_TCP_PORT_RANGE=50000,51000
+fi;


Property changes on: trunk/tests/sites/communicado/communicado_sanity.source.sh
___________________________________________________________________
Added: svn:executable
   + *

Added: trunk/tests/sites/communicado/communicado_sanity.swift
===================================================================
--- trunk/tests/sites/communicado/communicado_sanity.swift	                        (rev 0)
+++ trunk/tests/sites/communicado/communicado_sanity.swift	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,11 @@
+type file;
+
+app (file out, file err) remote_driver ()
+{
+    date stdout=@filename(out) stderr=@filename(err);
+}
+
+file driver_out <simple_mapper; prefix="sanity", suffix=".out">;
+file driver_err <simple_mapper; prefix="sanity", suffix=".err">;
+
+(driver_out, driver_err) = remote_driver();
\ No newline at end of file

Added: trunk/tests/sites/communicado/communicado_sanity.timeout
===================================================================
--- trunk/tests/sites/communicado/communicado_sanity.timeout	                        (rev 0)
+++ trunk/tests/sites/communicado/communicado_sanity.timeout	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1 @@
+300

Added: trunk/tests/sites/communicado/sites.template.xml
===================================================================
--- trunk/tests/sites/communicado/sites.template.xml	                        (rev 0)
+++ trunk/tests/sites/communicado/sites.template.xml	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,16 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<config xmlns="http://www.ci.uchicago.edu/swift/SwiftSites">
+
+  <pool handle="communicado">
+    <execution provider="coaster" jobmanager="ssh-cl:local" url="communicado.ci.uchicago.edu"/>
+    <profile namespace="globus" key="jobsPerNode">2</profile>
+    <profile namespace="globus" key="lowOverAllocation">100</profile>
+    <profile namespace="globus" key="highOverAllocation">100</profile>
+    <profile namespace="globus" key="maxtime">36000</profile>
+    <profile namespace="globus" key="maxWalltime">01:05:00</profile>
+    <profile namespace="karajan" key="jobThrottle">0.0799</profile>
+    <profile namespace="karajan" key="initialScore">10000</profile>
+    <profile namespace="globus" key="userHomeOverride">/home/{env.USER}/swiftwork</profile>
+    <workdirectory>/home/{env.USER}/swiftwork</workdirectory>
+  </pool>
+</config>
\ No newline at end of file

Added: trunk/tests/sites/communicado/swift.properties
===================================================================
--- trunk/tests/sites/communicado/swift.properties	                        (rev 0)
+++ trunk/tests/sites/communicado/swift.properties	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,8 @@
+use.provider.staging=true
+use.wrapper.staging=false
+wrapperlog.always.transfer=true
+execution.retries=0
+lazy.errors=false
+provider.staging.pin.swiftfiles=false
+sitedir.keep=true
+#tcp.port.range=60000,61000
\ No newline at end of file

Added: trunk/tests/sites/communicado/tc.template.data
===================================================================
--- trunk/tests/sites/communicado/tc.template.data	                        (rev 0)
+++ trunk/tests/sites/communicado/tc.template.data	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,7 @@
+local  date /bin/date null null null
+beagle date /bin/date null null null
+uc3    date /bin/date null null null
+mcs    date /bin/date null null null
+midway date /bin/date null null null
+communicado date /bin/date null null null
+bridled date /bin/date null null null
\ No newline at end of file

Added: trunk/tests/sites/communicado/title.txt
===================================================================
--- trunk/tests/sites/communicado/title.txt	                        (rev 0)
+++ trunk/tests/sites/communicado/title.txt	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1 @@
+Communicado remote sanity test

Added: trunk/tests/sites/fusion/fusion_sanity.setup.sh
===================================================================
--- trunk/tests/sites/fusion/fusion_sanity.setup.sh	                        (rev 0)
+++ trunk/tests/sites/fusion/fusion_sanity.setup.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,11 @@
+#!/bin/bash
+
+USERNAME=$FUSION_USERNAME
+
+if [[ -z $USERNAME ]] 
+then
+    echo "Remote username not provided. Skipping sites configs"
+else
+    ls *xml
+    cat sites.xml  | sed "s/{env.USER}/$USERNAME/" > tmp && mv tmp sites.xml
+fi


Property changes on: trunk/tests/sites/fusion/fusion_sanity.setup.sh
___________________________________________________________________
Added: svn:executable
   + *

Added: trunk/tests/sites/fusion/fusion_sanity.source.sh
===================================================================
--- trunk/tests/sites/fusion/fusion_sanity.source.sh	                        (rev 0)
+++ trunk/tests/sites/fusion/fusion_sanity.source.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,6 @@
+#!/bin/bash
+if [ "$HOSTNAME" == "midway001" ]
+then
+   export GLOBUS_HOSTNAME=swift.rcc.uchicago.edu
+   export GLOBUS_TCP_PORT_RANGE=50000,51000
+fi;


Property changes on: trunk/tests/sites/fusion/fusion_sanity.source.sh
___________________________________________________________________
Added: svn:executable
   + *

Added: trunk/tests/sites/fusion/fusion_sanity.swift
===================================================================
--- trunk/tests/sites/fusion/fusion_sanity.swift	                        (rev 0)
+++ trunk/tests/sites/fusion/fusion_sanity.swift	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,11 @@
+type file;
+
+app (file out, file err) remote_driver ()
+{
+    date stdout=@filename(out) stderr=@filename(err);
+}
+
+file driver_out <simple_mapper; prefix="sanity", suffix=".out">;
+file driver_err <simple_mapper; prefix="sanity", suffix=".err">;
+
+(driver_out, driver_err) = remote_driver();
\ No newline at end of file

Added: trunk/tests/sites/fusion/fusion_sanity.timeout
===================================================================
--- trunk/tests/sites/fusion/fusion_sanity.timeout	                        (rev 0)
+++ trunk/tests/sites/fusion/fusion_sanity.timeout	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1 @@
+300

Added: trunk/tests/sites/fusion/sites.template.xml
===================================================================
--- trunk/tests/sites/fusion/sites.template.xml	                        (rev 0)
+++ trunk/tests/sites/fusion/sites.template.xml	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,18 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<config xmlns="http://www.ci.uchicago.edu/swift/SwiftSites">
+
+   <pool handle="fusion">
+      <execution jobmanager="ssh-cl:pbs" provider="coaster" url="fusion.lcrc.anl.gov"/>
+      <filesystem provider="local" url="none" />
+      <profile namespace="globus" key="maxWallTime">00:00:30</profile>
+      <profile namespace="globus" key="jobsPerNode">2</profile>
+      <profile namespace="globus" key="slots">1</profile>
+      <profile namespace="globus" key="nodeGranularity">2</profile>
+      <profile namespace="globus" key="maxNodes">2</profile>
+      <profile namespace="globus" key="queue">shared</profile>
+      <profile namespace="karajan" key="jobThrottle">1.00</profile>
+      <profile namespace="karajan" key="initialScore">10000</profile>
+      <workdirectory>/homes/{env.USER}/swiftwork</workdirectory>
+   </pool>
+</config>
+

Added: trunk/tests/sites/fusion/swift.properties
===================================================================
--- trunk/tests/sites/fusion/swift.properties	                        (rev 0)
+++ trunk/tests/sites/fusion/swift.properties	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,8 @@
+use.provider.staging=true
+use.wrapper.staging=false
+wrapperlog.always.transfer=true
+execution.retries=0
+lazy.errors=false
+provider.staging.pin.swiftfiles=false
+sitedir.keep=true
+tcp.port.range=50000,51000
\ No newline at end of file

Added: trunk/tests/sites/fusion/tc.template.data
===================================================================
--- trunk/tests/sites/fusion/tc.template.data	                        (rev 0)
+++ trunk/tests/sites/fusion/tc.template.data	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,7 @@
+local  date /bin/date null null null
+beagle date /bin/date null null null
+uc3    date /bin/date null null null
+mcs    date /bin/date null null null
+midway date /bin/date null null null
+blues  date /bin/date null null null
+fusion date /bin/date null null null

Added: trunk/tests/sites/fusion/title.txt
===================================================================
--- trunk/tests/sites/fusion/title.txt	                        (rev 0)
+++ trunk/tests/sites/fusion/title.txt	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1 @@
+Fusion remote sanity test

Modified: trunk/tests/stress/IO/bagOnodes/sites.template.xml
===================================================================
--- trunk/tests/stress/IO/bagOnodes/sites.template.xml	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/stress/IO/bagOnodes/sites.template.xml	2013-10-06 19:51:29 UTC (rev 7138)
@@ -1,4 +1,5 @@
-<config>
+<?xml version="1.0" encoding="UTF-8"?>
+<config xmlns="http://www.ci.uchicago.edu/swift/SwiftSites">
 
   <pool handle="crank">
     <execution provider="coaster" jobmanager="ssh-cl:local" url="crank.mcs.anl.gov"/>

Modified: trunk/tests/stress/IO/beagle/sites.template.xml
===================================================================
--- trunk/tests/stress/IO/beagle/sites.template.xml	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/stress/IO/beagle/sites.template.xml	2013-10-06 19:51:29 UTC (rev 7138)
@@ -1,4 +1,5 @@
-<config>
+<?xml version="1.0" encoding="UTF-8"?>
+<config xmlns="http://www.ci.uchicago.edu/swift/SwiftSites">
   <pool handle="beagle">
     <execution provider="coaster" jobmanager="ssh-cl:pbs" url="login4.beagle.ci.uchicago.edu"/>
     <profile namespace="globus" key="jobsPerNode">24</profile>
@@ -6,7 +7,8 @@
     <profile namespace="globus" key="highOverAllocation">100</profile>
     <profile namespace="globus" key="providerAttributes">pbs.aprun;pbs.mpp;depth=24</profile>
     <profile namespace="globus" key="maxtime">3700</profile>
-    <profile namespace="globus" key="maxWalltime">01:00:00</profile>
+    <profile namespace="globus" key="maxWalltime">00:25:00</profile>
+    <profile namespace="globus" key="queue">development</profile>
     <profile namespace="globus" key="userHomeOverride">/lustre/beagle/{env.USER}/swiftwork</profile>
     <profile namespace="globus" key="slots">20</profile>
     <profile namespace="globus" key="maxnodes">10</profile>

Modified: trunk/tests/stress/internals/swift.properties
===================================================================
--- trunk/tests/stress/internals/swift.properties	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/stress/internals/swift.properties	2013-10-06 19:51:29 UTC (rev 7138)
@@ -5,3 +5,4 @@
 status.mode=provider
 use.provider.staging=false
 provider.staging.pin.swiftfiles=false
+use.wrapper.staging=false
\ No newline at end of file

Modified: trunk/tests/stress/internals/tc.template.data
===================================================================
--- trunk/tests/stress/internals/tc.template.data	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/stress/internals/tc.template.data	2013-10-06 19:51:29 UTC (rev 7138)
@@ -1,2 +1,2 @@
 local bash /bin/bash null null null
-
+local sleep /bin/sleep null null null

Modified: trunk/tests/stress/internals/x_foreach.swift
===================================================================
--- trunk/tests/stress/internals/x_foreach.swift	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/stress/internals/x_foreach.swift	2013-10-06 19:51:29 UTC (rev 7138)
@@ -2,16 +2,16 @@
 	Foreach loops with variable number of loops
 	to be called with cmdline arg -loops=<Number>
 
-#NIGHTLY 10000 100000  
+#NIGHTLY 10000 100000
 #WEEKLY  1000 10000 1000000
 */
 
-int limit   = @toint(@arg("loops")); 
+int limit   = @toint(@arg("loops"));
 int result[];
 
-foreach num, index in [1:limit:1] {
+foreach num, index in [0:limit-1:1] {
 	result[index] = index;
 }
 
 tracef("Result[0]   = %i \n", result[0]);
-tracef("Result[%i]  = %i \n", limit, result[limit]);
\ No newline at end of file
+tracef("Result[%i]  = %i \n", limit, result[limit-1]);

Modified: trunk/tests/stress/internals/x_recursion.args
===================================================================
--- trunk/tests/stress/internals/x_recursion.args	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/stress/internals/x_recursion.args	2013-10-06 19:51:29 UTC (rev 7138)
@@ -1 +1 @@
--loops=10000 
+-loops=1000

Added: trunk/tests/user_test.sh
===================================================================
--- trunk/tests/user_test.sh	                        (rev 0)
+++ trunk/tests/user_test.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,29 @@
+export BEAGLE_USERNAME="yadunandb"
+export MIDWAY_USERNAME="yadunand"
+export MCS_USERNAME="yadunand"
+export UC3_USERNAME="yadunand"
+export BLUES_USERNAME="yadunand"
+export FUSION_USERNAME="yadunand"
+export COMM_USERNAME="yadunandb"
+export BRID_USERNAME="yadunandb"
+export FROM_MAIL="Test-Engine at midway001"
+export TO_MAIL="yadudoc1729 at gmail.com"
+
+export REMOTE_DRIVER_FASTSETUP="true"
+#export REMOTE_DRIVER_FASTSETUP="false"
+export KILL_JAVA="false"
+
+# Extra performance stats
+export COG_OPTS=-Dtcp.channel.log.io.performance=true
+
+# To run swift from a tar ball set following variable
+export SWIFT_TAR_FILE="/scratch/midway/yadunand/swift-trunk.tar"
+
+#export RUN_TYPE="daily"
+export RUN_TYPE="test"
+
+if [ "midway001" == "midway001" ]
+then
+   export GLOBUS_HOSTNAME=swift.rcc.uchicago.edu
+   export GLOBUS_TCP_PORT_RANGE=50000,51000
+fi;
\ No newline at end of file


Property changes on: trunk/tests/user_test.sh
___________________________________________________________________
Added: svn:executable
   + *

Added: trunk/tests/user_yadu.sh
===================================================================
--- trunk/tests/user_yadu.sh	                        (rev 0)
+++ trunk/tests/user_yadu.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -0,0 +1,28 @@
+export BEAGLE_USERNAME="yadunandb"
+export MIDWAY_USERNAME="yadunand"
+export MCS_USERNAME="yadunand"
+export UC3_USERNAME="yadunand"
+export BLUES_USERNAME="yadunand"
+export FUSION_USERNAME="yadunand"
+export COMM_USERNAME="yadunandb"
+export BRID_USERNAME="yadunandb"
+export FROM_MAIL="Test-Engine at midway001"
+export TO_MAIL="yadudoc1729 at gmail.com"
+
+#export REMOTE_DRIVER_FASTSETUP="false"
+export REMOTE_DRIVER_FASTSETUP="true"
+export SWIFT_TAR_FILE="/scratch/midway/yadunand/swift-trunk.tar"
+
+export KILL_JAVA="false"
+
+# Extra performance stats
+export COG_OPTS=-Dtcp.channel.log.io.performance=true
+
+export RUN_TYPE="daily"
+#export RUN_TYPE="test"
+
+if [ "midway001" == "midway001" ]
+then
+   export GLOBUS_HOSTNAME=swift.rcc.uchicago.edu
+   export GLOBUS_TCP_PORT_RANGE=50000,51000
+fi;
\ No newline at end of file


Property changes on: trunk/tests/user_yadu.sh
___________________________________________________________________
Added: svn:executable
   + *




More information about the Swift-commit mailing list
--- trunk/tests/groups/group-daily-remote.sh	2013-10-06 15:54:22 UTC (rev 7137)
+++ trunk/tests/groups/group-daily-remote.sh	2013-10-06 19:51:29 UTC (rev 7138)
@@ -1,28 +1,66 @@
 # GROUPLIST definition to run all local tests
 
-GROUPLIST=( # Remote sanity test-group
-            $TESTDIR/sites/remote_sanity/beagle \
-            $TESTDIR/sites/remote_sanity/mcs    \
-            $TESTDIR/sites/remote_sanity/midway \
-            $TESTDIR/sites/remote_sanity/uc3    \
-	    # Frisbee will fail due to Bug 1030  
-            $TESTDIR/sites/remote_sanity/mac-frisbee  \
+GROUPLIST=( $TESTDIR/language/working \
+            $TESTDIR/local \
+            $TESTDIR/language/should-not-work \
+            # $TESTDIR/cdm \
+            # $TESTDIR/cdm/ps \
+            # $TESTDIR/cdm/star
+            $TESTDIR/language-behaviour/arrays \
+            $TESTDIR/language-behaviour/broken \
+	        $TESTDIR/language-behaviour/compounds \
+            $TESTDIR/language-behaviour/control_structures \
+            $TESTDIR/language-behaviour/datatypes \
+	        $TESTDIR/language-behaviour/IO \
+	        $TESTDIR/language-behaviour/logic \
+	        $TESTDIR/language-behaviour/mappers \
+	        $TESTDIR/language-behaviour/math \
+	        $TESTDIR/language-behaviour/params \
+            $TESTDIR/language-behaviour/procedures \
+            $TESTDIR/language-behaviour/strings \
+	        $TESTDIR/language-behaviour/variables \
+	        $TESTDIR/language-behaviour/cleanup \
+      	    $TESTDIR/bugs \
+	        $TESTDIR/documentation/tutorial \
+            $TESTDIR/functions \
 
-            # Remote-cluster IO tests
-	    $TESTDIR/stress/IO/beagle \
+            # Site testing test-group
+            $TESTDIR/sites/beagle \
+            $TESTDIR/sites/mcs    \
+            $TESTDIR/sites/midway \
+            $TESTDIR/sites/uc3    \
+	        # Frisbee will fail due to Bug 1030
+            $TESTDIR/sites/mac-frisbee  \
+            $TESTDIR/sites/blues  \
+            $TESTDIR/sites/fusion \
+            $TESTDIR/sites/raven  \
+
+ 	        # Remote-cluster IO tests
+	        $TESTDIR/stress/IO/beagle \
             $TESTDIR/stress/IO/bagOnodes \
             $TESTDIR/stress/IO/multiple \
             $TESTDIR/stress/IO/uc3 \
 
-	    # Remote-cluster Apps tests - MODIS
+            # Language stress tests
+            $TESTDIR/stress/internals \
+
+	        # Remote-cluster Apps tests - MODIS
             $TESTDIR/stress/apps/modis_beagle  \
             $TESTDIR/stress/apps/modis_local   \
-	    $TESTDIR/stress/apps/modis_midway  \
-	    $TESTDIR/stress/apps/modis_uc3     \
-            $TESTDIR/stress/apps/modis_multiple\
+	        $TESTDIR/stress/apps/modis_midway  \
+	        $TESTDIR/stress/apps/modis_uc3     \
+            # $TESTDIR/stress/apps/modis_multiple\
 
-	    # Recursive Test invocation        
-    	    $TESTDIR/multi_remote	       \
+            # Local stress tests
+            $TESTDIR/stress/internals \
+            # Local cluster tests.
+            $TESTDIR/stress/local_cluster \
+            $TESTDIR/stress/random_fail \
+            $TESTDIR/stress/jobs_per_node \
+
+       	    # Recursive Test invocation
+	        $TESTDIR/multi_remote
+
           )
 
 checkvars WORK

Added: trunk/tests/groups/group-remote-sanity.sh
===================================================================